#!/bin/bash 

# This script constructs, via aunfold, an approximated unfolding with depth=1 for the example of mutual exclusion. 
# Input: mutual.xml (in GTXL standard for graph transformation systems).
# Output: out.xml (in GXL standard for the Petri graph obtained by the construction of the approximated unfolding).

# By the means of pg2lola convert out.xml to LoLa-format - will be needed for the backward reachability algorithm (bwra)

# We use the bwra tool to check whether a marking is coverable.
# Input: out.xml (Petri graph) and marking file (taken from the hyper-graph visualisation). Output on terminal whether the marking is coverable.

# the script also generates a visualisation of the example: 
# pg2neato extracts the Petri net and hypergraph components of the Petri graph. 
# Input: out.xml
# Output: neatoInput.petriNet / neatoInput.hypergraph files
# By the means of the dot/neato programs the following files are constructed: 
# out.pn.ps: a visualisation of the Petri net 
# out.hg.ps: a visualisation of the hypergraph. 

if [ -f out.xml ]
then 
rm out.xml
fi 

if [ -f ../../example/mutual.xml ]
then 

#approximated unfolding constructed
./../../bin/aunfold ../../example/mutual.xml out.xml   

if [ -f out.xml ]
then 


# ------ Visualisation ------
#extract the Petri net and hypergraph components and transform them to neato/dot input format
./../../bin/pg2neato -pn out.xml > neatoInput.petriNet
./../../bin/pg2neato -hg out.xml > neatoInput.hypergraph

#See Graphviz documentation at http://www.research.att.com/sw/tools/graphviz for additional details on dot and neato.
if [ -f neatoInput.petriNet ]
then
dot -Tps -Goverlap=false neatoInput.petriNet > out.pn.ps                
else echo "Missing neatoInput.petriNet file"
fi 

if [ -f neatoInput.hypergraph ]
then
neato -Tps -Goverlap=false neatoInput.hypergraph > out.hg.ps
else echo "Missing neatoInput.hypergraph file"
fi 
# ---------------------------



if [ -f out_lola ]
then 
rm out_lola
fi

#convert to LoLa-format - will be needed for backward reachability algorithm (bwra)
./../../bin/pg2lola out.xml > out_lola

if [ -f out_lola ]
then

if [ -f marking ]
then

#check whether a marking is coverable. 


./../../bin/bwra out_lola marking

else echo "Error in sponge: no marking file constructed!"
fi # marking
 
else echo "Error in pg2lola: no out_lola file constructed!"
fi # out_lola

else  "Error in aunfold: no out.xml constructed!"
fi # out

else echo "Missing mutual.xml file!"
fi # mutual.xml 
